summaryrefslogtreecommitdiffstats
path: root/khtml/dom
diff options
context:
space:
mode:
Diffstat (limited to 'khtml/dom')
-rw-r--r--khtml/dom/css_extensions.cpp6
-rw-r--r--khtml/dom/css_extensions.h8
-rw-r--r--khtml/dom/css_value.h2
-rw-r--r--khtml/dom/dom_doc.cpp4
-rw-r--r--khtml/dom/dom_string.cpp18
-rw-r--r--khtml/dom/dom_string.h2
-rw-r--r--khtml/dom/html_block.h6
-rw-r--r--khtml/dom/html_form.h2
-rw-r--r--khtml/dom/html_image.cpp2
-rw-r--r--khtml/dom/html_image.h12
-rw-r--r--khtml/dom/html_inline.cpp2
-rw-r--r--khtml/dom/html_inline.h12
-rw-r--r--khtml/dom/html_table.h26
13 files changed, 51 insertions, 51 deletions
diff --git a/khtml/dom/css_extensions.cpp b/khtml/dom/css_extensions.cpp
index 01a47d5f1..23f7739dc 100644
--- a/khtml/dom/css_extensions.cpp
+++ b/khtml/dom/css_extensions.cpp
@@ -1881,15 +1881,15 @@ void CSS2Properties::setTop( const DOMString &value )
if(impl) ((ElementImpl *)impl)->setAttribute("top", value);
}
-DOMString CSS2Properties::tqunicodeBidi() const
+DOMString CSS2Properties::unicodeBidi() const
{
if(!impl) return 0;
- return ((ElementImpl *)impl)->getAttribute("tqunicodeBidi");
+ return ((ElementImpl *)impl)->getAttribute("unicodeBidi");
}
void CSS2Properties::setUnicodeBidi( const DOMString &value )
{
- if(impl) ((ElementImpl *)impl)->setAttribute("tqunicodeBidi", value);
+ if(impl) ((ElementImpl *)impl)->setAttribute("unicodeBidi", value);
}
DOMString CSS2Properties::verticalAlign() const
diff --git a/khtml/dom/css_value.h b/khtml/dom/css_value.h
index 7523a2797..5d4a043c7 100644
--- a/khtml/dom/css_value.h
+++ b/khtml/dom/css_value.h
@@ -633,7 +633,7 @@ class RectImpl;
/**
* The \c Rect interface is used to represent any <a
- * href="http://www.w3.org/TR/REC-CSS2/visufx.html#value-def-tqshape">
+ * href="http://www.w3.org/TR/REC-CSS2/visufx.html#value-def-shape">
* rect </a> value. This interface reflects the values in the
* underlying style property. Hence, modifications made through this
* interface modify the style property.
diff --git a/khtml/dom/dom_doc.cpp b/khtml/dom/dom_doc.cpp
index 088a7a94a..0ff123444 100644
--- a/khtml/dom/dom_doc.cpp
+++ b/khtml/dom/dom_doc.cpp
@@ -112,8 +112,8 @@ HTMLDocument DOMImplementation::createHTMLDocument( const DOMString& title )
r->open();
- r->write(TQString::tqfromLatin1("<HTML><HEAD><TITLE>") + title.string() +
- TQString::tqfromLatin1("</TITLE></HEAD>"));
+ r->write(TQString::fromLatin1("<HTML><HEAD><TITLE>") + title.string() +
+ TQString::fromLatin1("</TITLE></HEAD>"));
return r;
}
diff --git a/khtml/dom/dom_string.cpp b/khtml/dom/dom_string.cpp
index f8487cf5a..14bdc2613 100644
--- a/khtml/dom/dom_string.cpp
+++ b/khtml/dom/dom_string.cpp
@@ -39,7 +39,7 @@ DOMString::DOMString(const TQString &str)
return;
}
- impl = new DOMStringImpl( str.tqunicode(), str.length() );
+ impl = new DOMStringImpl( str.unicode(), str.length() );
impl->ref();
}
@@ -193,10 +193,10 @@ bool DOMString::percentage(int &_percentage) const
return true;
}
-TQChar *DOMString::tqunicode() const
+TQChar *DOMString::unicode() const
{
if(!impl) return 0;
- return impl->tqunicode();
+ return impl->unicode();
}
TQString DOMString::string() const
@@ -225,8 +225,8 @@ bool DOM::strcasecmp( const DOMString &as, const DOMString &bs )
{
if ( as.length() != bs.length() ) return true;
- const TQChar *a = as.tqunicode();
- const TQChar *b = bs.tqunicode();
+ const TQChar *a = as.unicode();
+ const TQChar *b = bs.unicode();
if ( a == b ) return false;
if ( !( a && b ) ) return true;
int l = as.length();
@@ -239,7 +239,7 @@ bool DOM::strcasecmp( const DOMString &as, const DOMString &bs )
bool DOM::strcasecmp( const DOMString &as, const char* bs )
{
- const TQChar *a = as.tqunicode();
+ const TQChar *a = as.unicode();
int l = as.length();
if ( !bs ) return ( l != 0 );
while ( l-- ) {
@@ -265,7 +265,7 @@ bool DOM::operator==( const DOMString &a, const DOMString &b )
if( l != b.length() ) return false;
- if(!memcmp(a.tqunicode(), b.tqunicode(), l*sizeof(TQChar)))
+ if(!memcmp(a.unicode(), b.unicode(), l*sizeof(TQChar)))
return true;
return false;
}
@@ -276,7 +276,7 @@ bool DOM::operator==( const DOMString &a, const TQString &b )
if( l != b.length() ) return false;
- if(!memcmp(a.tqunicode(), b.tqunicode(), l*sizeof(TQChar)))
+ if(!memcmp(a.unicode(), b.unicode(), l*sizeof(TQChar)))
return true;
return false;
}
@@ -291,7 +291,7 @@ bool DOM::operator==( const DOMString &a, const char *b )
const TQChar *aptr = aimpl->s;
while ( alen-- ) {
unsigned char c = *b++;
- if ( !c || ( *aptr++ ).tqunicode() != c )
+ if ( !c || ( *aptr++ ).unicode() != c )
return false;
}
}
diff --git a/khtml/dom/dom_string.h b/khtml/dom/dom_string.h
index dec259882..3d4706b5a 100644
--- a/khtml/dom/dom_string.h
+++ b/khtml/dom/dom_string.h
@@ -97,7 +97,7 @@ public:
*/
DOMString upper() const;
- TQChar *tqunicode() const;
+ TQChar *unicode() const;
TQString string() const;
int toInt() const;
diff --git a/khtml/dom/html_block.h b/khtml/dom/html_block.h
index b318d8cb9..4283bafa2 100644
--- a/khtml/dom/html_block.h
+++ b/khtml/dom/html_block.h
@@ -105,7 +105,7 @@ public:
~HTMLDivElement();
/**
- * Horizontal text tqalignment. See the <a
+ * Horizontal text alignment. See the <a
* href="http://www.w3.org/TR/REC-html40/present/graphics.html#adef-align">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
@@ -231,7 +231,7 @@ public:
~HTMLHeadingElement();
/**
- * Horizontal text tqalignment. See the <a
+ * Horizontal text alignment. See the <a
* href="http://www.w3.org/TR/REC-html40/present/graphics.html#adef-align">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
@@ -272,7 +272,7 @@ public:
~HTMLParagraphElement();
/**
- * Horizontal text tqalignment. See the <a
+ * Horizontal text alignment. See the <a
* href="http://www.w3.org/TR/REC-html40/present/graphics.html#adef-align">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
diff --git a/khtml/dom/html_form.h b/khtml/dom/html_form.h
index ef318ba06..0623e421b 100644
--- a/khtml/dom/html_form.h
+++ b/khtml/dom/html_form.h
@@ -798,7 +798,7 @@ public:
void setAccessKey( const DOMString & );
/**
- * Text tqalignment relative to \c FIELDSET . See the <a
+ * Text alignment relative to \c FIELDSET . See the <a
* href="http://www.w3.org/TR/REC-html40/interact/forms.html#adef-align-LEGEND">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
diff --git a/khtml/dom/html_image.cpp b/khtml/dom/html_image.cpp
index a5cdb3b71..f7c9dac26 100644
--- a/khtml/dom/html_image.cpp
+++ b/khtml/dom/html_image.cpp
@@ -122,7 +122,7 @@ void HTMLAreaElement::setNoHref( bool _noHref )
}
}
-DOMString HTMLAreaElement::tqshape() const
+DOMString HTMLAreaElement::shape() const
{
if(!impl) return DOMString();
return ((ElementImpl *)impl)->getAttribute(ATTR_SHAPE);
diff --git a/khtml/dom/html_inline.cpp b/khtml/dom/html_inline.cpp
index 9f40da2fb..568761685 100644
--- a/khtml/dom/html_inline.cpp
+++ b/khtml/dom/html_inline.cpp
@@ -148,7 +148,7 @@ void HTMLAnchorElement::setRev( const DOMString &value )
if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_REV, value);
}
-DOMString HTMLAnchorElement::tqshape() const
+DOMString HTMLAnchorElement::shape() const
{
if(!impl) return DOMString();
return ((ElementImpl *)impl)->getAttribute(ATTR_SHAPE);
diff --git a/khtml/dom/html_table.h b/khtml/dom/html_table.h
index 72e38d7fe..6b9a2d99d 100644
--- a/khtml/dom/html_table.h
+++ b/khtml/dom/html_table.h
@@ -63,7 +63,7 @@ public:
~HTMLTableCaptionElement();
/**
- * Caption tqalignment with respect to the table. See the <a
+ * Caption alignment with respect to the table. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-align-CAPTION">
* align attribute definition </a> in HTML 4.0. This attribute is
* deprecated in HTML 4.0.
@@ -134,7 +134,7 @@ public:
void setAbbr( const DOMString & );
/**
- * Horizontal tqalignment of data in cell. See the <a
+ * Horizontal alignment of data in cell. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-align-TD">
* align attribute definition </a> in HTML 4.0.
*
@@ -187,7 +187,7 @@ public:
void setCh( const DOMString & );
/**
- * Offset of tqalignment character. See the <a
+ * Offset of alignment character. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-charoff">
* charoff attribute definition </a> in HTML 4.0.
*
@@ -281,7 +281,7 @@ public:
void setScope( const DOMString & );
/**
- * Vertical tqalignment of data in cell. See the <a
+ * Vertical alignment of data in cell. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-valign">
* valign attribute definition </a> in HTML 4.0.
*
@@ -338,7 +338,7 @@ public:
~HTMLTableColElement();
/**
- * Horizontal tqalignment of cell data in column. See the <a
+ * Horizontal alignment of cell data in column. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-align-TD">
* align attribute definition </a> in HTML 4.0.
*
@@ -364,7 +364,7 @@ public:
void setCh( const DOMString & );
/**
- * Offset of tqalignment character. See the <a
+ * Offset of alignment character. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-charoff">
* charoff attribute definition </a> in HTML 4.0.
*
@@ -391,7 +391,7 @@ public:
void setSpan( long );
/**
- * Vertical tqalignment of cell data in column. See the <a
+ * Vertical alignment of cell data in column. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-valign">
* valign attribute definition </a> in HTML 4.0.
*
@@ -790,7 +790,7 @@ public:
void setCells( const HTMLCollection & );
/**
- * Horizontal tqalignment of data within cells of this row. See the
+ * Horizontal alignment of data within cells of this row. See the
* <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-align-TD">
* align attribute definition </a> in HTML 4.0.
@@ -831,7 +831,7 @@ public:
void setCh( const DOMString & );
/**
- * Offset of tqalignment character. See the <a
+ * Offset of alignment character. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-charoff">
* charoff attribute definition </a> in HTML 4.0.
*
@@ -844,7 +844,7 @@ public:
void setChOff( const DOMString & );
/**
- * Vertical tqalignment of data within cells of this row. See the <a
+ * Vertical alignment of data within cells of this row. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-valign">
* valign attribute definition </a> in HTML 4.0.
*
@@ -913,7 +913,7 @@ public:
~HTMLTableSectionElement();
/**
- * Horizontal tqalignment of data in cells. See the \c align
+ * Horizontal alignment of data in cells. See the \c align
* attribute for HTMLTheadElement for details.
*
*/
@@ -938,7 +938,7 @@ public:
void setCh( const DOMString & );
/**
- * Offset of tqalignment character. See the <a
+ * Offset of alignment character. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/tables.html#adef-charoff">
* charoff attribute definition </a> in HTML 4.0.
*
@@ -951,7 +951,7 @@ public:
void setChOff( const DOMString & );
/**
- * Vertical tqalignment of data in cells. See the \c valign
+ * Vertical alignment of data in cells. See the \c valign
* attribute for HTMLTheadElement for details.
*
*/
diff --git a/khtml/dom/css_extensions.h b/khtml/dom/css_extensions.h
index bda2cfbbc..a6cdb2149 100644
--- a/khtml/dom/css_extensions.h
+++ b/khtml/dom/css_extensions.h
@@ -2515,14 +2515,14 @@ public:
/**
* See the <a
* href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-tqunicode-bidi">
* tqunicode-bidi property definition </a> in CSS2.
*
*/
- DOM::DOMString tqunicodeBidi() const;
+ DOM::DOMString unicodeBidi() const;
/**
- * see tqunicodeBidi
+ * see unicodeBidi
*/
void setUnicodeBidi( const DOM::DOMString & );
@@ -2515,14 +2515,14 @@ public:
/**
* See the <a
- * href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-tqunicode-bidi">
- * tqunicode-bidi property definition </a> in CSS2.
+ * href="http://www.w3.org/TR/REC-CSS2/visuren.html#propdef-unicode-bidi">
+ * unicode-bidi property definition </a> in CSS2.
*
*/
diff --git a/khtml/dom/html_image.h b/khtml/dom/html_image.h
index 9b1334c83..9f30aaa14 100644
--- a/khtml/dom/html_image.h
+++ b/khtml/dom/html_image.h
@@ -90,7 +90,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
* geometry. See also \c tqshape for the tqshape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
* coords attribute definition </a> in HTML 4.0.
@@ -131,16 +131,16 @@ public:
void setNoHref( bool );
/**
* The tqshape of the active area. The coordinates are given by
* \c coords . See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-tqshape">
* tqshape attribute definition </a> in HTML 4.0.
*
*/
- DOMString tqshape() const;
+ DOMString shape() const;
/**
- * see tqshape
+ * see shape
*/
void setShape( const DOMString & );
@@ -90,7 +90,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
- * geometry. See also \c tqshape for the tqshape of the
+ * geometry. See also \c shape for the shape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
@@ -131,16 +131,16 @@ public:
void setNoHref( bool );
/**
- * The tqshape of the active area. The coordinates are given by
+ * The shape of the active area. The coordinates are given by
* \c coords . See the <a
@@ -131,16 +131,16 @@ public:
* \c coords . See the <a
- * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-tqshape">
- * tqshape attribute definition </a> in HTML 4.0.
+ * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-shape">
+ * shape attribute definition </a> in HTML 4.0.
*
*/
diff --git a/khtml/dom/html_inline.h b/khtml/dom/html_inline.h
index 041c43db0..f92ed6917 100644
--- a/khtml/dom/html_inline.h
+++ b/khtml/dom/html_inline.h
@@ -89,7 +89,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
* geometry. See also \c tqshape for the tqshape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
* coords attribute definition </a> in HTML 4.0.
@@ -168,16 +168,16 @@ public:
void setRev( const DOMString & );
/**
* The tqshape of the active area. The coordinates are given by
* \c coords . See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-tqshape">
* tqshape attribute definition </a> in HTML 4.0.
*
*/
- DOMString tqshape() const;
+ DOMString shape() const;
/**
- * see tqshape
+ * see shape
*/
void setShape( const DOMString & );
@@ -89,7 +89,7 @@ public:
/**
* Comma-separated list of lengths, defining an active region
- * geometry. See also \c tqshape for the tqshape of the
+ * geometry. See also \c shape for the shape of the
* region. See the <a
* href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-coords">
@@ -168,16 +168,16 @@ public:
void setRev( const DOMString & );
/**
- * The tqshape of the active area. The coordinates are given by
+ * The shape of the active area. The coordinates are given by
* \c coords . See the <a
@@ -168,16 +168,16 @@ public:
* \c coords . See the <a
- * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-tqshape">
- * tqshape attribute definition </a> in HTML 4.0.
+ * href="http://www.w3.org/TR/REC-html40/struct/objects.html#adef-shape">
+ * shape attribute definition </a> in HTML 4.0.
*
*/